==> refcomp-services-0.1.jar: fr/inra/refcomp/services/ServiceFactory.java <==
/*
 * #%L
 * Refcomp :: services
 * 
 * $Id: ServiceFactory.java 79 2011-01-27 17:45:56Z jcouteau $
 * $HeadURL: svn+ssh://jcouteau@scm.mulcyber.toulouse.inra.fr/svnroot/refcomp/tags/refcomp-0.1/refcomp-services/src/main/java/fr/inra/refcomp/services/ServiceFactory.java $
 * %%
 * Copyright (C) 2010 Inra
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package fr.inra.refcomp.services;

import fr.inra.refcomp.entities.AgentImpl;
import fr.inra.refcomp.entities.AgentSkillImpl;
import fr.inra.refcomp.entities.CatiImpl;
import fr.inra.refcomp.entities.DepartmentImpl;
import fr.inra.refcomp.entities.FrequencyImpl;
import fr.inra.refcomp.entities.NatureImpl;
import fr.inra.refcomp.entities.SkillImpl;
import fr.inra.refcomp.entities.UnitDeptLinkImpl;
import fr.inra.refcomp.entities.UnitImpl;
import fr.inra.refcomp.entities.UserImpl;
import java.util.Arrays;
import java.util.List;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.nuiton.util.converter.ConverterUtil;
import org.nuiton.wikitty.WikittyProxy;
import org.nuiton.wikitty.WikittyService;
import org.nuiton.wikitty.WikittyServiceFactory;
import org.nuiton.wikitty.addons.WikittyImportExportService;
import org.nuiton.wikitty.entities.WikittyExtension;
import org.nuiton.wikitty.entities.WikittyTreeNodeImpl;
import org.nuiton.wikitty.entities.WikittyUserImpl;

/**
 * User: couteau
 * Date: 26 nov. 2010
 */
public class ServiceFactory {

    /**
     * Log.
     */
    private static final Log log = LogFactory.getLog(ServiceFactory.class);

    /**
     * Wikitty service (cached version) for remote access.
     */
    protected static WikittyService wikittyService;

    /**
     * Single instance of frequency service.
     */
    // FIXME jcouteau 19/01/2011 problème de sécu ?
    protected static StorageService storageService;

    /**
     * Single instance of importExport service.
     */
    protected static WikittyImportExportService importExportService;

    protected static RefcompConfiguration config;

    static {
        // TODO jcouteau 26/11/2010 Gotten from vradi, maybe better way to do it
        try {
            ConverterUtil.initConverters();
            config = RefcompConfiguration.getInstance();
        } catch (Exception eee) {
            log.error("Cant initialize Service factory : ", eee);
        }
    }

    public static synchronized StorageService getStorageService(RefcompSession session) {
        if (storageService == null) {
            WikittyProxy proxy = getProxy(session);
            updateExtensions(proxy);
            storageService = new StorageServiceImpl(proxy, config);
        }
        return storageService;
    }

    /**
     * Creates wikitty service (cached).
     * <p/>
     * Constructor added for UI embedded mode, with custom configuration.
     *
     * @return a unique instance of WikittyService
     */
    public static WikittyService getWikittyService() {
        if (wikittyService == null) {
            synchronized (ServiceFactory.class) {
                if(wikittyService == null) {
                    wikittyService = WikittyServiceFactory.buildWikittyService(config);
                }
            }
        }

        return wikittyService;
    }

    /**
     * Creates wikitty service (cached).
     * <p/>
     * Constructor added for UI embedded mode, with custom configuration.
     *
     * @return a unique instance of WikittyService
     */
    public static WikittyImportExportService getImportExportService(WikittyProxy proxy) {
        if (importExportService == null) {
            synchronized (ServiceFactory.class) {
                if (importExportService == null) {
                    importExportService = new WikittyImportExportService(config,
                            proxy.getSecurityToken(),
                            proxy.getWikittyService());
                }
            }
        }

        return importExportService;
    }

    /**
     * Creates wikitty proxy.
     *
     * @param session the user session.
     *
     * @return a unique instance of WikittyProxy.
     */
    public static WikittyProxy getProxy(RefcompSession session) {
        StorageService service = getService(session);
        WikittyProxy proxy = service.getProxy();
        return proxy;
    }

    public static StorageService getService(RefcompSession session) {
        StorageService service = session.getService();
        if (service == null) {
            WikittyService wService = getWikittyService();
            // init proxy on cached service
            WikittyProxy proxy = new WikittyProxy(wService);
            service = new StorageServiceImpl(proxy, config);
            session.setService(service);
        }
        return service;
    }

    /**
     * Register all extensions.
     * <p/>
     * Already existing extensions with same version are skipped,
     * new extension are created and stored.
     *
     * @param localWikittyProxy wikitty proxy
     */
    protected static void updateExtensions(WikittyProxy localWikittyProxy) {

        // easier if ordered
        List<WikittyExtension> extensions = Arrays.asList(
                AgentImpl.extensionAgent,
                AgentSkillImpl.extensionAgentSkill,
                CatiImpl.extensionCati,
                DepartmentImpl.extensionDepartment,
                FrequencyImpl.extensionFrequency,
                NatureImpl.extensionNature,
                SkillImpl.extensionSkill,
                UnitImpl.extensionUnit,
                UnitDeptLinkImpl.extensionUnitDeptLink,
                UserImpl.extensionUser,
                WikittyTreeNodeImpl.extensionWikittyTreeNode,
                WikittyUserImpl.extensionWikittyUser);

        localWikittyProxy.storeExtension(extensions);
        if (log.isDebugEnabled()){
            log.debug("Migration done");
        }
    }

}

==> refcomp-services-1.5.jar: fr/inra/refcomp/services/ServiceFactory.java <==
/*
 * #%L
 * Refcomp :: services
 * 
 * $Id: ServiceFactory.java 191 2011-06-19 10:06:39Z jcouteau $
 * $HeadURL: svn+ssh://jcouteau@scm.mulcyber.toulouse.inra.fr/svnroot/refcomp/tags/refcomp-1.5.1/refcomp-services/src/main/java/fr/inra/refcomp/services/ServiceFactory.java $
 * %%
 * Copyright (C) 2010 Inra
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package fr.inra.refcomp.services;

import fr.inra.refcomp.entities.AgentImpl;
import fr.inra.refcomp.entities.AgentSkillImpl;
import fr.inra.refcomp.entities.CatiImpl;
import fr.inra.refcomp.entities.DepartmentImpl;
import fr.inra.refcomp.entities.FrequencyImpl;
import fr.inra.refcomp.entities.NatureImpl;
import fr.inra.refcomp.entities.SkillImpl;
import fr.inra.refcomp.entities.UnitDeptLinkImpl;
import fr.inra.refcomp.entities.UnitImpl;
import fr.inra.refcomp.entities.UserImpl;
import java.util.Arrays;
import java.util.List;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.nuiton.wikitty.WikittyProxy;
import org.nuiton.wikitty.WikittyService;
import org.nuiton.wikitty.WikittyServiceFactory;
import org.nuiton.wikitty.addons.WikittyImportExportService;
import org.nuiton.wikitty.entities.WikittyExtension;
import org.nuiton.wikitty.entities.WikittyTreeNodeImpl;
import org.nuiton.wikitty.entities.WikittyUserImpl;

/**
 * User: couteau
 * Date: 26 nov. 2010
 */
public class ServiceFactory {

    /**
     * Log.
     */
    private static final Log log = LogFactory.getLog(ServiceFactory.class);

    /**
     * Wikitty service (cached version) for remote access.
     */
    protected static WikittyService wikittyService;

    /**
     * Single instance of importExport service.
     */
    protected static WikittyImportExportService importExportService;

    protected static RefcompConfiguration config = RefcompConfiguration.getInstance();

    /**
     * Creates wikitty service (cached).
     * <p/>
     * Constructor added for UI embedded mode, with custom configuration.
     *
     * @return a unique instance of WikittyService
     */
    public static WikittyService getWikittyService() {
        if (wikittyService == null) {
            synchronized (ServiceFactory.class) {
                if(wikittyService == null) {
                    wikittyService = WikittyServiceFactory.buildWikittyService(config);
                }
            }
        }

        return wikittyService;
    }

    /**
     * Creates wikitty service (cached).
     * <p/>
     * Constructor added for UI embedded mode, with custom configuration.
     *
     * @return a unique instance of WikittyService
     */
    public static WikittyImportExportService getImportExportService(WikittyProxy proxy) {
        if (importExportService == null) {
            synchronized (ServiceFactory.class) {
                if (importExportService == null) {
                    importExportService = new WikittyImportExportService(config,
                            proxy.getSecurityToken(),
                            proxy.getWikittyService());
                }
            }
        }

        return importExportService;
    }

    public static StorageService getService(RefcompSession session) {
        StorageService service = session.getService();
        if (service == null) {
            if (log.isDebugEnabled()) {
                log.debug("Initiate service");
            }
            WikittyService wService = getWikittyService();
            // init proxy on cached service
            WikittyProxy proxy = new WikittyProxy(wService);
            updateExtensions(proxy);
            service = new StorageServiceImpl(proxy, config);
            session.setService(service);
        }
        return service;
    }

    /**
     * Register all extensions.
     * <p/>
     * Already existing extensions with same version are skipped,
     * new extension are created and stored.
     *
     * @param localWikittyProxy wikitty proxy
     */
    protected static void updateExtensions(WikittyProxy localWikittyProxy) {

        // easier if ordered
        List<WikittyExtension> extensions = Arrays.asList(
                AgentImpl.extensionAgent,
                AgentSkillImpl.extensionAgentSkill,
                CatiImpl.extensionCati,
                DepartmentImpl.extensionDepartment,
                FrequencyImpl.extensionFrequency,
                NatureImpl.extensionNature,
                SkillImpl.extensionSkill,
                UnitImpl.extensionUnit,
                UnitDeptLinkImpl.extensionUnitDeptLink,
                UserImpl.extensionUser,
                WikittyTreeNodeImpl.extensionWikittyTreeNode,
                WikittyUserImpl.extensionWikittyUser);

        localWikittyProxy.storeExtension(extensions);
        if (log.isDebugEnabled()){
            log.debug("Migration done");
        }
    }

}
